import apiResponse from "../../utils/apiResponse";
import express from "express";
import HttpError from "http-errors";
import axios from "axios";
import { openGate } from "../../utils/gate/openGate";
import * as dotenv from "dotenv";

dotenv.config();

export const qrCheckIn = async (p:string, v:string) => {
  const userId = process.env.USER_ID;
  const password = process.env.PASSWORD;
  const machineType = process.env.MACHINE_TYPE;
  const apiUrl = process.env.API_URL;
  const machineId = process.env.MACHINE_ID;
  const centerCode = process.env.CENTER_CODE;
  const login = await axios
  .post(`${apiUrl}/api/v1/login`, {
    userId,
    password,
    machineType,
    machineId,
  });
  const result = await axios.post(
    `${apiUrl}/api/v1/que/checkVehEntry`,
    {
      codeParamP: p,
      codeParamV: v,
      machineId,
      centerCode,
    },
    {
      headers: { Cookie: login.headers["set-cookie"]![0] },
    }
  );
  if (result.data) {
    console.log(result.data.resultMsg)
    if (result.data.result == 'F-9102') {
      await openGate();
    }
  }
}

export default async function (req: express.Request, res: express.Response) {
  try {
    const { codeParamP, codeParamV, plateNo, vehCat, bookingType, centerCode, machineId, apiUrl, sessionId } =
      req.body as any;

    const isQr = codeParamP && codeParamV;

    const result = await axios.post(
        `${apiUrl}/api/v1/que/checkVehEntry`,
        {
          plateNo,
          vehCat,
          bookingType,
          machineId,
          centerCode,
        },
        {
          headers: { Cookie: sessionId },
        }
      );
      
      // result.data;
    if (result.data) {
      if (result.data.result == 'F-9102') {
        await openGate();
      }
      return apiResponse(res, "CheckIn", "1.0", result.data);
    } else {
      return apiResponse(res, "CheckIn", "1.0", {
        error: "failed to checkin",
      });
    }
  } catch (err) {
    // @ts-ignore
    console.log("potential error:",err?.response?.data?.resultMsg)
    return apiResponse(res, "CheckIn", "1.0", {
       //@ts-ignore
      error: err?.response?.data?.resultMsg || "failed to checkin",
    }, 500);
  }
}
