import express from "express";
import { HttpError } from "http-errors";

export function errorHandler(
  err: Error,
  req: express.Request,
  res: express.Response,
  next: express.NextFunction
) {
  let code = 500;
  if (err instanceof HttpError) {
    code = err.statusCode;
  }
  res.status(code).json({ code, message: err.message }).end();
}

export function handlerWrapper(
  fn: express.RequestHandler
): express.RequestHandler {
  return async function (req, res, next) {
    try {
      await fn(req, res, next);
    } catch (err) {
      console.error(err);
      next(err);
    }
  };
}
