import { exit } from "process";
import { Sequelize } from "sequelize-typescript";

export function initSequelize() {
  if (!sequelize) {
    const sequelizeInstance = new Sequelize({
      dialect: "postgres",
      port: Number(process.env.PG_PORT || 5432),
      database: process.env.PG_DB || "postgres",
      username: process.env.PG_USER || "admin",
      password: process.env.PG_PASSWORD || "test",
      ssl: true,

      ...(process.env.PG_HOST_READER
        ? {
            replication: {
              read: [
                { host: process.env.PG_HOST_READER },
                { host: process.env.PG_HOST },
              ],
              write: { host: process.env.PG_HOST },
            },
          }
        : { host: process.env.PG_HOST || "127.0.0.1" }),

      dialectOptions: {
        application_name: `${process.env.APP_NAME} (${process.env.ENV})`,
        useUTC: false,
        statement_timeout: 200000,
      },

      timezone: "Asia/Hong_Kong",
      logQueryParameters: true,
      // logging: function(query, time) {
      //     return false;
      //     // if (time && time > 10) {
      //     //     console.log(query, `Time: ${time} ms`);
      //     // }
      // },
      benchmark: true,
      models: [__dirname + "/models/**"],
    });
    sequelizeInstance
      .authenticate({ logging: false })
      .then(() => {
        console.log("Database Connected");
      })
      .catch((err) => {
        console.error("Sequelize Database Connection Failed", err);
        process.exit(1);
      });
    return sequelizeInstance;
  }
  return sequelize;
}
export const sequelize: Sequelize | undefined = initSequelize();
