import axios from "axios";
import net from "net";

export const callControllerByTCP = (id:number, enable:boolean) => new Promise((resolve, reject) =>  {
  const client = new net.Socket();

  client.on('data', function(data) {
    console.log(data);
    client.destroy();
  });

  client.on('close', function() {
    console.log('Connection closed');
    resolve(true);
  });

  client.on('ready', function () {
    console.log("Connected TCP");
    const command = [0x00, 0x03];

    const data1 = Array(32).fill(0x00);
    const data2 = Array(32).fill(0x00);

    const payload = [0xF0, 0xF0, ...command, ...data1, ...data2, 0xF0, 0xF0];

    const crc = 0 - payload.reduce((prev, curr) => prev+curr, 0);
    client.write(new Uint8Array([...payload, crc]));
    console.log("Sent Command");
  });

  client.connect(50000, "192.168.168.125");
});

export async function callController(id:number, enable:boolean) {
  const action = enable?"SHORT":"OPEN";
  const state = `${action}${id}`;

  const controllerPath = process.env.CONTROLLER_PATH || "192.168.168.125";

  try {
    console.log(`http://${controllerPath}/status.cgi?redirect=iostatus.htm&failure=fail.htm&type=io_state_change&state=${state}`);
    await axios.get(`http://${controllerPath}/status.cgi?redirect=iostatus.htm&failure=fail.htm&type=io_state_change&state=${state}`, {
      auth: {
        username: "admin",
        password: "admin"
      }
    });
    return true;
  } catch (error:any) {
    console.error(error.message);
    return false;
  }
}